var searchData=
[
  ['or_20decode_20file_20or_20standard_20input_20to_20standard_20output_0',['base64url: Base64Url encode or decode FILE, or standard input, to standard output.',['../md_tools_2base64url_2README.html',1,'']]],
  ['orcania_20library_1',['Orcania library',['../index.html',1,'']]],
  ['output_2',['base64url: Base64Url encode or decode FILE, or standard input, to standard output.',['../md_tools_2base64url_2README.html',1,'']]]
];
